==> ibrdos-react-native-components-1.0.4.tgz: package/components/Image.tsx <==
import * as React from 'react';
import {Image as _Image} from 'react-native';
import FastImage, {FastImageProps} from 'react-native-fast-image';

export type ImageProps = FastImageProps & {
    source: string | number,
    priority?: 'low' | 'normal' | 'high' | undefined,
    resizeMode?: 'cover' | 'contain' | 'stretch' | 'center' | undefined,
    style?: any,
}

export default function Image(props: ImageProps): JSX.Element {
    const {
        source,
        priority = 'normal',
        resizeMode = 'contain',
        style,
        ...otherProps
    } = props;

    const [computedWidth, setComputedWidth] = React.useState(style?.width);
    const [computedHeight, setComputedHeight] = React.useState(style?.height);

    React.useEffect(() => {
        const {width, height} = style;

        if (width && height) {
            setComputedWidth(width);
            setComputedHeight(height);
        }

        if (width && !height) {
            setComputedWidth(width);

            if (source && typeof source === 'string') {
                _Image.getSize(source, (w, h) => {
                    setComputedHeight(width * h / w);
                });
            }
        }

        if (!width && height) {
            setComputedHeight(height);

            if (source && typeof source === 'string') {
                _Image.getSize(source, (w, h) => {
                    setComputedWidth(height * w / h);
                });
            }
        }
    }, [source, style]);

    return (
        <FastImage
            {...otherProps}
            source={typeof source === 'string' ? {
                uri: source,
                priority,
            } : source}
            resizeMode={resizeMode}
            style={[{
                width: computedWidth,
                height: computedHeight,
            }, style]}
        />
    );
}

==> ibrdos-react-native-components-1.0.13.tgz: package/components/Image.tsx <==
import * as React from 'react';
import {Image as _Image} from 'react-native';
import FastImage, {FastImageProps} from 'react-native-fast-image';

export type ImageProps = FastImageProps & {
    source: string | number,
    priority?: 'low' | 'normal' | 'high' | undefined,
    resizeMode?: 'cover' | 'contain' | 'stretch' | 'center' | undefined,
    style?: any,
}

export default function Image(props: ImageProps): JSX.Element {
    const {
        source,
        priority = 'normal',
        resizeMode = 'contain',
        style,
        ...otherProps
    } = props;

    const [computedWidth, setComputedWidth] = React.useState(style?.width);
    const [computedHeight, setComputedHeight] = React.useState(style?.height);

    React.useEffect(() => {
        const {width, height} = style || {};

        if (width && height) {
            setComputedWidth(width);
            setComputedHeight(height);
        }

        if (width && !height) {
            setComputedWidth(width);

            if (source && typeof source === 'string') {
                _Image.getSize(source, (w, h) => {
                    setComputedHeight(width * h / w);
                });
            }
        }

        if (!width && height) {
            setComputedHeight(height);

            if (source && typeof source === 'string') {
                _Image.getSize(source, (w, h) => {
                    setComputedWidth(height * w / h);
                });
            }
        }
    }, [source, style]);

    return (
        <FastImage
            {...otherProps}
            source={typeof source === 'string' ? {
                uri: source,
                priority,
            } : source}
            resizeMode={resizeMode}
            style={[{
                width: computedWidth,
                height: computedHeight,
            }, style]}
        />
    );
}
